/**
 * This work was created by participants in the DataONE project, and is
 * jointly copyrighted by participating institutions in DataONE. For
 * more information on DataONE, see our web site at http://dataone.org.
 *
 *   Copyright ${year}
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dataone.service.mn.tier1.v1;

import java.util.Date;

import org.dataone.service.exceptions.InsufficientResources;
import org.dataone.service.exceptions.InvalidRequest;
import org.dataone.service.exceptions.InvalidToken;
import org.dataone.service.exceptions.NotAuthorized;
import org.dataone.service.exceptions.NotImplemented;
import org.dataone.service.exceptions.ServiceFailure;
import org.dataone.service.types.v1.Event;
import org.dataone.service.types.v1.Log;
import org.dataone.service.types.v1.Node;
import org.dataone.service.types.v1.Session;



/**
 * The DataONE Member Node Tier 1 Core interface.  This defines an
 * implementation interface for Member Nodes that wish to build an
 * implementation that is compliant with the DataONE service definitions.
 *
 * @author Matthew Jones, Rob Nahf
 */
public interface MNCore {

	public final static String SERVICE_VERSION = "v1";
	
	
    /**
     * @see https://purl.dataone.org/architecturev2/apis/MN_APIs.html#MN_core.ping
     */
    public Date ping() 
    throws NotImplemented, ServiceFailure, InsufficientResources;

    /** 
     * @see https://purl.dataone.org/architecturev2/apis/MN_APIs.html#MN_core.getLogRecords
     */
    public Log getLogRecords(Date fromDate, Date toDate, 
           Event event, String pidFilter, Integer start, Integer count) 
    throws InvalidRequest, InvalidToken, NotAuthorized, NotImplemented, ServiceFailure;


    /**
     * @see https://purl.dataone.org/architecturev2/apis/MN_APIs.html#MN_core.getCapabilities
     */
    public Node getCapabilities() 
    throws NotImplemented, ServiceFailure;

    
////    
    /** 
     * @see https://purl.dataone.org/architecturev2/apis/MN_APIs.html#MN_core.getLogRecords
     */
    @Deprecated
    public Log getLogRecords(Session session, Date fromDate, Date toDate, 
           Event event, String pidFilter, Integer start, Integer count) 
    throws InvalidRequest, InvalidToken, NotAuthorized, NotImplemented, ServiceFailure;

}
